AgentService

Struct AgentService 

pub struct AgentService;
Service for agent-related operations.

Implementations

Source

impl AgentService

pub async fn spawn( town: &Town, name: &str, cli: Option<&str>, ) -> Result<SpawnResult>

Spawn a new agent.

pub async fn spawn_with_metadata( town: &Town, name: &str, cli: Option<&str>, role_id: Option<&str>, nickname: Option<&str>, parent_agent_id: Option<AgentId>, spawn_mode: Option<SpawnMode>, ) -> Result<SpawnResult>

Spawn a new agent with extended metadata (role, nickname, parent).

pub async fn list(town: &Town) -> Result<Vec<AgentInfo>>

List all agents with their current status.

pub async fn status(town: &Town) -> Result<TownStatus>

Get town status including all agents.

pub async fn kill(channel: &Channel, agent_id: AgentId) -> Result<()>

Kill (stop) an agent gracefully.

pub async fn stop_all(town: &Town) -> Result<Vec<Agent>>

Request all non-terminal agents in a town to stop gracefully.

pub async fn restart(channel: &Channel, agent_id: AgentId) -> Result<()>

Restart a stopped agent.

pub async fn prune(town: &Town, all: bool) -> Result<Vec<Agent>>

Prune stopped/stale agents.

pub async fn interrupt(channel: &Channel, agent_id: AgentId) -> Result<()>

Interrupt (pause) a running agent.

Sets the agent’s state to Paused. The agent will not pick up new work until resumed.

pub async fn wait( channel: &Channel, agent_id: AgentId, timeout: Option<Duration>, ) -> Result<Agent>

Wait for an agent to reach a terminal state.

Polls the agent state at 1-second intervals until the agent is in a terminal state or the timeout expires. Returns the final agent state.

pub async fn resume(channel: &Channel, agent_id: AgentId) -> Result<()>

Resume a paused agent.

Sets the agent’s state back to Idle so it can accept new work.

pub async fn close(channel: &Channel, agent_id: AgentId) -> Result<()>

Close an agent: drain its current work and then stop.

Sets the agent to Draining state, which means it will finish its current task but won’t accept new work. Then requests a stop.

pub async fn list_open(town: &Town) -> Result<Vec<AgentInfo>>

List all agents that are not in a terminal state.

pub async fn get_result( channel: &Channel, agent_id: AgentId, ) -> Result<Option<Task>>

Get the result of an agent’s most recently completed task.